;;; This file was automatically generated by SWIG (https://www.swig.org).
;;; Version 4.2.1
;;;
;;; Do not make changes to this file unless you know what you are doing - modify
;;; the SWIG interface file instead.

(define-module (nlopt))


(load-extension "nlopt_guile" "SWIG_init")

(set! NLOPT-GN-DIRECT (NLOPT-GN-DIRECT))
(set! NLOPT-GN-DIRECT-L (NLOPT-GN-DIRECT-L))
(set! NLOPT-GN-DIRECT-L-RAND (NLOPT-GN-DIRECT-L-RAND))
(set! NLOPT-GN-DIRECT-NOSCAL (NLOPT-GN-DIRECT-NOSCAL))
(set! NLOPT-GN-DIRECT-L-NOSCAL (NLOPT-GN-DIRECT-L-NOSCAL))
(set! NLOPT-GN-DIRECT-L-RAND-NOSCAL (NLOPT-GN-DIRECT-L-RAND-NOSCAL))
(set! NLOPT-GN-ORIG-DIRECT (NLOPT-GN-ORIG-DIRECT))
(set! NLOPT-GN-ORIG-DIRECT-L (NLOPT-GN-ORIG-DIRECT-L))
(set! NLOPT-GD-STOGO (NLOPT-GD-STOGO))
(set! NLOPT-GD-STOGO-RAND (NLOPT-GD-STOGO-RAND))
(set! NLOPT-LD-LBFGS-NOCEDAL (NLOPT-LD-LBFGS-NOCEDAL))
(set! NLOPT-LD-LBFGS (NLOPT-LD-LBFGS))
(set! NLOPT-LN-PRAXIS (NLOPT-LN-PRAXIS))
(set! NLOPT-LD-VAR1 (NLOPT-LD-VAR1))
(set! NLOPT-LD-VAR2 (NLOPT-LD-VAR2))
(set! NLOPT-LD-TNEWTON (NLOPT-LD-TNEWTON))
(set! NLOPT-LD-TNEWTON-RESTART (NLOPT-LD-TNEWTON-RESTART))
(set! NLOPT-LD-TNEWTON-PRECOND (NLOPT-LD-TNEWTON-PRECOND))
(set! NLOPT-LD-TNEWTON-PRECOND-RESTART (NLOPT-LD-TNEWTON-PRECOND-RESTART))
(set! NLOPT-GN-CRS2-LM (NLOPT-GN-CRS2-LM))
(set! NLOPT-GN-MLSL (NLOPT-GN-MLSL))
(set! NLOPT-GD-MLSL (NLOPT-GD-MLSL))
(set! NLOPT-GN-MLSL-LDS (NLOPT-GN-MLSL-LDS))
(set! NLOPT-GD-MLSL-LDS (NLOPT-GD-MLSL-LDS))
(set! NLOPT-LD-MMA (NLOPT-LD-MMA))
(set! NLOPT-LN-COBYLA (NLOPT-LN-COBYLA))
(set! NLOPT-LN-NEWUOA (NLOPT-LN-NEWUOA))
(set! NLOPT-LN-NEWUOA-BOUND (NLOPT-LN-NEWUOA-BOUND))
(set! NLOPT-LN-NELDERMEAD (NLOPT-LN-NELDERMEAD))
(set! NLOPT-LN-SBPLX (NLOPT-LN-SBPLX))
(set! NLOPT-LN-AUGLAG (NLOPT-LN-AUGLAG))
(set! NLOPT-LD-AUGLAG (NLOPT-LD-AUGLAG))
(set! NLOPT-LN-AUGLAG-EQ (NLOPT-LN-AUGLAG-EQ))
(set! NLOPT-LD-AUGLAG-EQ (NLOPT-LD-AUGLAG-EQ))
(set! NLOPT-LN-BOBYQA (NLOPT-LN-BOBYQA))
(set! NLOPT-GN-ISRES (NLOPT-GN-ISRES))
(set! NLOPT-AUGLAG (NLOPT-AUGLAG))
(set! NLOPT-AUGLAG-EQ (NLOPT-AUGLAG-EQ))
(set! NLOPT-G-MLSL (NLOPT-G-MLSL))
(set! NLOPT-G-MLSL-LDS (NLOPT-G-MLSL-LDS))
(set! NLOPT-LD-SLSQP (NLOPT-LD-SLSQP))
(set! NLOPT-LD-CCSAQ (NLOPT-LD-CCSAQ))
(set! NLOPT-GN-ESCH (NLOPT-GN-ESCH))
(set! NLOPT-GN-AGS (NLOPT-GN-AGS))
(set! NLOPT-NUM-ALGORITHMS (NLOPT-NUM-ALGORITHMS))
(set! NLOPT-FAILURE (NLOPT-FAILURE))
(set! NLOPT-INVALID-ARGS (NLOPT-INVALID-ARGS))
(set! NLOPT-OUT-OF-MEMORY (NLOPT-OUT-OF-MEMORY))
(set! NLOPT-ROUNDOFF-LIMITED (NLOPT-ROUNDOFF-LIMITED))
(set! NLOPT-FORCED-STOP (NLOPT-FORCED-STOP))
(set! NLOPT-NUM-FAILURES (NLOPT-NUM-FAILURES))
(set! NLOPT-SUCCESS (NLOPT-SUCCESS))
(set! NLOPT-STOPVAL-REACHED (NLOPT-STOPVAL-REACHED))
(set! NLOPT-FTOL-REACHED (NLOPT-FTOL-REACHED))
(set! NLOPT-XTOL-REACHED (NLOPT-XTOL-REACHED))
(set! NLOPT-MAXEVAL-REACHED (NLOPT-MAXEVAL-REACHED))
(set! NLOPT-MAXTIME-REACHED (NLOPT-MAXTIME-REACHED))
(set! NLOPT-NUM-RESULTS (NLOPT-NUM-RESULTS))

(export new-bad-cast
        delete-bad-cast
        new-bad-exception
        delete-bad-exception
        new-logic-error
        delete-logic-error
        new-domain-error
        delete-domain-error
        new-invalid-argument
        delete-invalid-argument
        new-length-error
        delete-length-error
        new-out-of-range
        delete-out-of-range
        new-runtime-error
        delete-runtime-error
        new-range-error
        delete-range-error
        new-overflow-error
        delete-overflow-error
        new-underflow-error
        delete-underflow-error
        new-nlopt-doublevector
        new-nlopt-doublevector
        new-nlopt-doublevector
        new-nlopt-doublevector
        nlopt-doublevector-length
        nlopt-doublevector-empty?
        nlopt-doublevector-clear!
        nlopt-doublevector-push!
        nlopt-doublevector-pop!
        nlopt-doublevector-ref
        nlopt-doublevector-set!
        delete-nlopt-doublevector
        NLOPT-GN-DIRECT
        NLOPT-GN-DIRECT-L
        NLOPT-GN-DIRECT-L-RAND
        NLOPT-GN-DIRECT-NOSCAL
        NLOPT-GN-DIRECT-L-NOSCAL
        NLOPT-GN-DIRECT-L-RAND-NOSCAL
        NLOPT-GN-ORIG-DIRECT
        NLOPT-GN-ORIG-DIRECT-L
        NLOPT-GD-STOGO
        NLOPT-GD-STOGO-RAND
        NLOPT-LD-LBFGS-NOCEDAL
        NLOPT-LD-LBFGS
        NLOPT-LN-PRAXIS
        NLOPT-LD-VAR1
        NLOPT-LD-VAR2
        NLOPT-LD-TNEWTON
        NLOPT-LD-TNEWTON-RESTART
        NLOPT-LD-TNEWTON-PRECOND
        NLOPT-LD-TNEWTON-PRECOND-RESTART
        NLOPT-GN-CRS2-LM
        NLOPT-GN-MLSL
        NLOPT-GD-MLSL
        NLOPT-GN-MLSL-LDS
        NLOPT-GD-MLSL-LDS
        NLOPT-LD-MMA
        NLOPT-LN-COBYLA
        NLOPT-LN-NEWUOA
        NLOPT-LN-NEWUOA-BOUND
        NLOPT-LN-NELDERMEAD
        NLOPT-LN-SBPLX
        NLOPT-LN-AUGLAG
        NLOPT-LD-AUGLAG
        NLOPT-LN-AUGLAG-EQ
        NLOPT-LD-AUGLAG-EQ
        NLOPT-LN-BOBYQA
        NLOPT-GN-ISRES
        NLOPT-AUGLAG
        NLOPT-AUGLAG-EQ
        NLOPT-G-MLSL
        NLOPT-G-MLSL-LDS
        NLOPT-LD-SLSQP
        NLOPT-LD-CCSAQ
        NLOPT-GN-ESCH
        NLOPT-GN-AGS
        NLOPT-NUM-ALGORITHMS
        NLOPT-FAILURE
        NLOPT-INVALID-ARGS
        NLOPT-OUT-OF-MEMORY
        NLOPT-ROUNDOFF-LIMITED
        NLOPT-FORCED-STOP
        NLOPT-NUM-FAILURES
        NLOPT-SUCCESS
        NLOPT-STOPVAL-REACHED
        NLOPT-FTOL-REACHED
        NLOPT-XTOL-REACHED
        NLOPT-MAXEVAL-REACHED
        NLOPT-MAXTIME-REACHED
        NLOPT-NUM-RESULTS
        new-nlopt-roundoff-limited
        delete-nlopt-roundoff-limited
        new-nlopt-forced-stop
        delete-nlopt-forced-stop
        new-nlopt-opt
        delete-nlopt-opt
        new-nlopt-opt
        new-nlopt-opt
        new-nlopt-opt
        nlopt-opt-optimize
        nlopt-opt-optimize
        nlopt-opt-last-optimize-result
        nlopt-opt-last-optimum-value
        nlopt-opt-get-algorithm
        nlopt-opt-get-algorithm-name
        nlopt-opt-get-dimension
        nlopt-opt-set-min-objective
        nlopt-opt-set-min-objective
        nlopt-opt-set-min-objective
        nlopt-opt-set-max-objective
        nlopt-opt-set-max-objective
        nlopt-opt-set-max-objective
        nlopt-opt-set-min-objective
        nlopt-opt-set-max-objective
        nlopt-opt-remove-inequality-constraints
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-inequality-mconstraint
        nlopt-opt-remove-equality-constraints
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-equality-mconstraint
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-inequality-constraint
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-equality-constraint
        nlopt-opt-add-inequality-mconstraint
        nlopt-opt-add-equality-mconstraint
        nlopt-opt-set-param
        nlopt-opt-get-param
        nlopt-opt-has-param
        nlopt-opt-nth-param
        nlopt-opt-num-params
        nlopt-opt-set-lower-bounds
        nlopt-opt-get-lower-bounds
        nlopt-opt-get-lower-bounds
        nlopt-opt-set-lower-bounds
        nlopt-opt-set-upper-bounds
        nlopt-opt-get-upper-bounds
        nlopt-opt-get-upper-bounds
        nlopt-opt-set-upper-bounds
        nlopt-opt-get-stopval
        nlopt-opt-set-stopval
        nlopt-opt-get-ftol-rel
        nlopt-opt-set-ftol-rel
        nlopt-opt-get-ftol-abs
        nlopt-opt-set-ftol-abs
        nlopt-opt-get-xtol-rel
        nlopt-opt-set-xtol-rel
        nlopt-opt-set-xtol-abs
        nlopt-opt-get-xtol-abs
        nlopt-opt-get-xtol-abs
        nlopt-opt-set-xtol-abs
        nlopt-opt-set-x-weights
        nlopt-opt-get-x-weights
        nlopt-opt-get-x-weights
        nlopt-opt-set-x-weights
        nlopt-opt-get-maxeval
        nlopt-opt-set-maxeval
        nlopt-opt-get-numevals
        nlopt-opt-get-maxtime
        nlopt-opt-set-maxtime
        nlopt-opt-get-force-stop
        nlopt-opt-set-force-stop
        nlopt-opt-force-stop
        nlopt-opt-get-errmsg
        nlopt-opt-set-local-optimizer
        nlopt-opt-get-population
        nlopt-opt-set-population
        nlopt-opt-get-vector-storage
        nlopt-opt-set-vector-storage
        nlopt-opt-set-initial-step
        nlopt-opt-set-initial-step
        nlopt-opt-set-default-initial-step
        nlopt-opt-get-initial-step
        nlopt-opt-get-exceptions-enabled
        nlopt-opt-set-exceptions-enabled
        nlopt-srand
        nlopt-srand-time
        nlopt-version
        nlopt-version-major
        nlopt-version-minor
        nlopt-version-bugfix
        nlopt-algorithm-name)
